#
# spec file for package switchboard
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover 3
%define         appid io.elementary.settings
Name:           switchboard
Version:        8.0.2
Release:        1.2
Summary:        Modular Desktop Settings Hub
License:        LGPL-2.1-or-later
URL:            https://github.com/elementary/switchboard
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.57.0
BuildRequires:  pkgconfig
BuildRequires:  sassc
BuildRequires:  vala
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(granite-7) >= 7.0.0
BuildRequires:  pkgconfig(gtk4) >= 3.10
BuildRequires:  pkgconfig(libadwaita-1) >= 1.4

%description
Switchboard is a modular system settings hub designed for the Pantheon desktop.

%lang_package

%package -n     lib%{name}-%{sover}-0
Summary:        Modular Desktop Settings Hub

%description -n lib%{name}-%{sover}-0
This package contains the shared library required to run the plugs.

%package        devel
Summary:        Development Files for %{name}
Requires:       lib%{name}-%{sover}-0 = %{version}

%description    devel
Switchboard is a modular system settings hub designed for the Pantheon desktop.

This package contains development files needed to develop plugins for
%{name}.

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}%{_datadir}

%ldconfig_scriptlets -n lib%{name}-%{sover}-0

%files
%license COPYING
%doc README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/metainfo/%{appid}.appdata.xml
%dir %{_datadir}/icons/hicolor/{128x128@2,128x128@2/apps,16x16@2,16x16@2/apps,24x24@2,24x24@2/apps,32x32@2,32x32@2/apps,64x64@2,64x64@2/apps}

%files -n lib%{name}-%{sover}-0
%{_libdir}/libswitchboard-%{sover}.so.*

%files devel
%{_includedir}/switchboard-%{sover}/
%{_libdir}/libswitchboard-%{sover}.so
%{_libdir}/pkgconfig/switchboard-%{sover}.pc
%{_datadir}/vala/vapi/switchboard-%{sover}.deps
%{_datadir}/vala/vapi/switchboard-%{sover}.vapi

%files lang -f %{appid}.lang

%changelog
* Tue Nov 12 2024 Richard Rahl <rrahl0@opensuse.org>
- Require switchboard at runtime
* Wed Nov  6 2024 Richard Rahl <rrahl0@opensuse.org>
- use ldconfig_scriptlets
- remove %%suse_update_desktop_file, as it's deprecated
* Wed Oct 23 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.2:
  * Updated translations
* Tue Sep 24 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.1:
  * Screen reader improvements
  * Updated translations
* Tue Aug 13 2024 Richard Rahl <rrahl0@opensuse.org>
- switch to %%{_datadir}/icons, so we can build for Leap
* Fri Aug  9 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * New redesigned app icon
  * New flatter and more responsive design
  * Smoother animations
  * Search results are more relevant and more clearly formatted
  * Use Portals when available
  * Back Buttons have a secondary-click menu for faster navigation
  * Window now has a reasonable minimum size
  * Updated translations
- update to 6.0.2:
  * Bundle app icon
  * Updated translations
- update to 6.0.1:
  * updated translations
- update to 6.0.0:
  * Add multitouch navigation gestures
  * Better support smaller displays
  * Remove old GNOME Control Center compatability layer
  * Stability and performance improvements
  * Updated translations
- update to 2.4.0:
  * Redesign search results view
  * Tab key moves focus out of search
  * Updated translations
- update to 2.3.9:
  * Updated translations
- update to 2.3.8:
  * Fix an issue that prevented tiling on small displays
  * Fix an issue with restoring the correct window size
  * Make the category grid fill the available space when maximized
  * Updated translations
- switch url to github, as we don't want to link to a different OS
* Mon Nov 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.3.7:
  * .github: Rename release.yml to release.md
  * Create release.yml
  * Add Release Action (#121)
  * Fix keyboard navigation issue (#117)
  * Fix missed unity bits (#116)
  * Add Lint to CI (#115)
  * Fix code style issues
  * Merge branch 'origin/master' into Weblate.
  * Delete CODE_OF_CONDUCT.md
  * Delete FUNDING.yml
  * CategoryFlowBox: GObject-style construction (#110)
  * CategoryIcon: GObject style, inline namespace (#111)
  * Drop LibUnity quicklists (#109)
  * Merge remote-tracking branch 'weblate/master'
  * Create FUNDING.yml
  * AppData: Add compulsory for Pantheon (#102)
* Mon Jul 15 2019 Alexei Podvalsky <avvissu@yandex.by>
- Add required dependencies: gsettings-backend-dconf
* Mon Mar  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.3.6:
  * Merge branch 'origin/master' into Weblate
  * Travis: add gettext dependency
  * Application: Add accel tooltip to back button (#97)
  * Clean up whitespace
  * Release 2.3.5
  * Rename Switchboard.vala to Application.vala (#95)
  * Link to plugs in README (#94)
  * Rewrite window state saving (#93)
  * Add missing languages to LINGUAS files (#90)
* Thu Dec 20 2018 Jan Engelhardt <jengelh@inai.de>
- Restore "the" in descriptions. Move summaries to Summary:.
* Thu Oct 18 2018 Alexei Podvalsky <avvissu@yandex.by>
- Remove accountsservice-ubuntu-schemas dependency
* Wed Oct 17 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.3.4:
  * Use the correct gettext domain (#89)
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.3.3:
  * Merge branch 'origin/master' into Weblate
  * RDNN binary name (#80)
  * Use GLib.Action accels for go back shortcut (#79)
  * Switchboard.vala: fix deprecated methods (#77)
- Switch to meson
* Fri Aug 17 2018 avvissu@yandex.by
- Update to 2.3.2:
  * Switch to Meson build system (#75)
  * Add EditorConfig
  * ReadMe: Add link to Valadoc (#74)
  * Add a screenshot to appdata (#69)
* Mon Jun 11 2018 avvissu@yandex.by
- Update to 2.3.1:
  * RDNN metadata (#61)
  * Valign category separators (#60)
  * plug: handle plug visibility the right way (#56)
  * plugs-manager: check for the .so suffix before doing anything
  * switchboard: use Gtk.Application instead of the deprecated
    Granite.Application (#57)
* Sat Jun  9 2018 avvissu@yandex.by
- Add accountsservice-ubuntu-schemas as required dependency
- Change the LIBDIR variable
- Remove obsolete macros
- Spec file cleanup
* Sat Jul 29 2017 avvissu@yandex.by
- Update to 2.3.0:
  * Update switchboard.appdata.xml.in (#41)
  * Create CODE_OF_CONDUCT.md (#38)
- Change the sourceurl to git
* Tue Jun 13 2017 jengelh@inai.de
- Clarify description.
* Mon Jun  5 2017 avvissu@yandex.by
- Remove required dependency: accountsservice-ubuntu-schemas
* Thu Feb  2 2017 avvissu@yandex.by
- Update to 2.2.1:
  * Fix printf being used before translating the string
  * Don't kill kittens
  * Handle can-show changes properly
  * Implement fallback to "parent" setting path
* Fri Dec  9 2016 avvissu@yandex.by
- Update to 2.2.0
* Sun Sep 18 2016 avvissu@yandex.by
- Update to 2.1.0
- Add macro glib2_gsettings_schema_requires
- Use macro: cmake and cmake_install
- Spec file cleanup
* Sat Feb 27 2016 mailaender@opensuse.org
- update to version 2.0.1
* Sat May 16 2015 mailaender@opensuse.org
- initial packaging of version 2.0.0
